@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2003-2012 Free Software Foundation, Inc.
+# Copyright (C) 2003-2018 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,12 +12,12 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Check that "make check" fails, when a DejaGnu test fails.
 
 required=runtest
-. ./defs || Exit 1
+. test-init.sh
 
 cat > faildeja << 'END'
 #! /bin/sh
@@ -50,7 +50,7 @@ $AUTOMAKE --add-missing
 
 ./configure
 
-$MAKE check && Exit 1
+$MAKE check && exit 1
 test -f faildeja.log
 test -f faildeja.sum
 $FGREP 'FAIL: failing_deja_test' faildeja.sum
