@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2002-2012 Free Software Foundation, Inc.
+# Copyright (C) 2002-2018 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,11 +12,11 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Make sure that PACKAGE and VERSION are AC_DEFINEd when requested.
 
-. ./defs || Exit 1
+. test-init.sh
 
 # First, check that PACKAGE and VERSION are output by default.
 
@@ -49,6 +49,6 @@ $AUTOCONF
 $AUTOMAKE # Dummy call to make sure Automake grok 'no-define' silently.
 ./configure
 
-grep 'DEFS.*-DVERSION=\\"UnIqUe' output && Exit 1
+grep 'DEFS.*-DVERSION=\\"UnIqUe' output && exit 1
 
 :
