@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2002-2014 Free Software Foundation, Inc.
+# Copyright (C) 2002-2018 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Test for PR automake/224: $(top_srcdir) w.r.t. dependencies.
 #
@@ -56,8 +56,8 @@ cd build
 ../configure
 
 $MAKE
-test -d foo/.deps
+test -f foo/.deps/main.Po
 $MAKE distclean
-test -d foo/.deps && exit 1
+test ! -e foo/.deps/main.Po
 
 :
